@@ -208,9 +208,11 @@ mfxStatus LoaderCtxVPL::SearchDirForLibs(STRING_TYPE searchDir,
                 if (libFound != libInfoList.end())
                     continue;
 
-                LibInfo *libInfo = new LibInfo;
-                if (!libInfo)
+                LibInfo *libInfo = new (std::nothrow) LibInfo;
+                if (!libInfo) {
+                    FindClose(hTestFile);
                     return MFX_ERR_MEMORY_ALLOC;
+                }
 
                 libInfo->libNameFull = libNameFull;
                 libInfo->libPriority = priority;
@@ -271,9 +273,11 @@ mfxStatus LoaderCtxVPL::SearchDirForLibs(STRING_TYPE searchDir,
                     continue;
                 }
 
-                LibInfo *libInfo = new LibInfo;
-                if (!libInfo)
+                LibInfo *libInfo = new (std::nothrow) LibInfo;
+                if (!libInfo) {
+                    closedir(pSearchDir);
                     return MFX_ERR_MEMORY_ALLOC;
+                }
 
                 libInfo->libNameFull = fullPath;
                 libInfo->libPriority = priority;
@@ -992,7 +996,7 @@ mfxStatus LoaderCtxVPL::QueryLibraryCaps() {
             UpdateImplPath(libInfo);
 
             for (mfxU32 i = 0; i < numImpls; i++) {
-                ImplInfo *implInfo = new ImplInfo;
+                ImplInfo *implInfo = new (std::nothrow) ImplInfo;
                 if (!implInfo)
                     return MFX_ERR_MEMORY_ALLOC;
 
@@ -1128,7 +1132,7 @@ mfxStatus LoaderCtxVPL::QueryLibraryCaps() {
                     msdkCtx->m_msdkAdapterD3D9 = msdkImplTab[i];
                 }
 
-                ImplInfo *implInfo = new ImplInfo;
+                ImplInfo *implInfo = new (std::nothrow) ImplInfo;
                 if (!implInfo)
                     return MFX_ERR_MEMORY_ALLOC;
 
